package com.cj.jiaqingjiayi.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cj.jiaqingjiayi.model.domain.Attribute;
import com.cj.jiaqingjiayi.model.vo.AttributeVO;
import com.cj.jiaqingjiayi.model.vo.SpecificationsVO;
import com.cj.jiaqingjiayi.service.AttributeService;
import com.cj.jiaqingjiayi.mapper.AttributeMapper;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

/**
* @author 高木
* @description 针对表【attribute(属性表)】的数据库操作Service实现
* @createDate 2024-08-21 16:29:45
*/
@Service
public class AttributeServiceImpl extends ServiceImpl<AttributeMapper, Attribute>
    implements AttributeService{

    @Override
    public List<SpecificationsVO> getBySpecificationsVoId(List<SpecificationsVO> specificationsVOList) {
        if (CollectionUtils.isEmpty(specificationsVOList)) {
            return specificationsVOList;
        }
        return specificationsVOList.stream().peek(item ->{
            Long specificationsId = item.getId();
            //根据规格id获取属性
            QueryWrapper<Attribute> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("specificationsId",specificationsId);
            List<Attribute> attributeList = this.list(queryWrapper);
            //获取属性脱敏信息
            List<AttributeVO> attributeVOList = getAttributeVOList(attributeList);
            item.setAttributeVOList(attributeVOList);
        }).collect(Collectors.toList());
    }

    /**
     * 获取脱敏属性列表
     * @param attributes 为脱敏列表
     * @return 脱敏列表
     */
    private List<AttributeVO> getAttributeVOList (List<Attribute> attributes) {
        if (CollectionUtils.isEmpty(attributes)) {
            return new ArrayList<>();
        }
        return attributes.stream().map(item -> {
            AttributeVO attributeVO = new AttributeVO();
            BeanUtils.copyProperties(item,attributeVO);
            return attributeVO;
        }).collect(Collectors.toList());
    }
}




