package com.cj.jiaqingjiayi.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cj.jiaqingjiayi.common.ErrorCode;
import com.cj.jiaqingjiayi.contant.CommonConstant;
import com.cj.jiaqingjiayi.exception.BusinessException;
import com.cj.jiaqingjiayi.exception.ThrowUtils;
import com.cj.jiaqingjiayi.model.domain.*;
import com.cj.jiaqingjiayi.model.request.business.BusinessQueryRequest;
import com.cj.jiaqingjiayi.model.request.manicurist.ManicuristQueryRequest;
import com.cj.jiaqingjiayi.service.*;
import com.cj.jiaqingjiayi.mapper.ManicuristMapper;
import com.cj.jiaqingjiayi.utils.RegexUtils;
import com.cj.jiaqingjiayi.utils.SqlUtils;
import lombok.Data;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Date;

/**
* @author 高木
* @description 针对表【manicurist(美甲师表)】的数据库操作Service实现
* @createDate 2024-09-23 19:23:08
*/
@Service
public class ManicuristServiceImpl extends ServiceImpl<ManicuristMapper, Manicurist>
    implements ManicuristService{

    @Resource
    private UserService userService;

    @Resource
    private BusinessService businessService;

    @Resource
    private ManicuristAuthService manicuristAuthService;

    @Override
    public void addManicurist(User user, Manicurist manicurist, ManicuristAuth manicuristAuth) {
        boolean save = userService.save(user);
        ThrowUtils.throwIf(!save, ErrorCode.OPERATION_ERROR, "添加美甲师失败");

        //美甲师绑定user
        manicurist.setUserId(user.getId());
        boolean save1 = this.save(manicurist);
        ThrowUtils.throwIf(!save1, ErrorCode.OPERATION_ERROR, "绑定id失败");
        //添加认证信息
        manicuristAuth.setArtistId(manicurist.getId());
        boolean save2 = manicuristAuthService.save(manicuristAuth);
        ThrowUtils.throwIf(!save2, ErrorCode.OPERATION_ERROR, "添加美甲师认证信息失败");
    }

    @Override
    public void validUser(User user, boolean add) {
        ThrowUtils.throwIf(user == null , ErrorCode.NULL_ERROR);

        String userAccount = user.getUserAccount();
        String userPassword = user.getUserPassword();

        if (add) {
            ThrowUtils.throwIf(StringUtils.isAllBlank(userAccount, userPassword), ErrorCode.PARAMS_ERROR);

            if (userAccount.length() < 4) {
                throw new BusinessException(ErrorCode.PARAMS_ERROR, "用户账号不符合要求");
            }

            if(userPassword.length() < 8) {
                throw new BusinessException(ErrorCode.PARAMS_ERROR, "用户密码不符合要求");
            }

            QueryWrapper<User> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("userAccount", userAccount);
            long count = userService.count(queryWrapper);
            if (count > 0) {
                throw new BusinessException(ErrorCode.PARAMS_ERROR, "账号重复");
            }
        }
    }

    @Override
    public void validManicurist(Manicurist manicurist, boolean add) {
        Long id = manicurist.getId();
        String manicuristName = manicurist.getName();
        String manicuristPhone = manicurist.getPhone();
        String gender = Integer.toString(manicurist.getGender());

        //只在添加时严格校验 保证商家信息是全的
        if (add) {
            if (StringUtils.isAnyBlank(manicuristName, manicuristPhone, gender)) {
                throw new BusinessException(ErrorCode.PARAMS_ERROR, "信息不全");
            }
        }

        if(!add){
            Manicurist byId = this.getById(id);
            ThrowUtils.throwIf(byId == null, ErrorCode.NULL_ERROR, "美甲师不存在");
        }

        if(StringUtils.isNotBlank(manicuristName)){
            QueryWrapper<Manicurist> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("name", manicuristName);
            long count = this.count(queryWrapper);
            ThrowUtils.throwIf(count > 0, ErrorCode.OPERATION_ERROR, "美甲师名称重复");
        }

        //校验手机号格式
        if (StringUtils.isNotBlank(manicuristPhone)) {
            boolean phoneInvalid = RegexUtils.isPhoneInvalid(manicuristPhone);
            ThrowUtils.throwIf(phoneInvalid, ErrorCode.PARAMS_ERROR, "手机号格式错误");

            QueryWrapper<Manicurist> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("Phone", manicuristPhone);
            long count = this.count(queryWrapper);
            ThrowUtils.throwIf(count > 0 , ErrorCode.OPERATION_ERROR, "手机号重复");
        }
    }

    @Override
    public void validManicuristAuth(ManicuristAuth manicuristAuth, boolean add) {
        //只在添加时严格校验 保证认证信息是全的
        if (add) {
            String certification_number = manicuristAuth.getCertification_number();
            String certificate_path = manicuristAuth.getCertificate_path();
            String issuing_authority = manicuristAuth.getIssuing_authority();
            if (StringUtils.isAnyBlank(certification_number, certificate_path, issuing_authority)) {
                throw new BusinessException(ErrorCode.PARAMS_ERROR, "美甲师认证信息不全");
            }
        }
    }

    @Override
    public void validManBus(Long businessId) {
        Business byId = businessService.getById(businessId);
        ThrowUtils.throwIf(byId == null, ErrorCode.NULL_ERROR, "商家不存在");
    }

    @Override
    public void deleteMan(long id) {
        Manicurist manicurist = this.getById(id);
        ThrowUtils.throwIf(manicurist == null, ErrorCode.OPERATION_ERROR, "删除的美甲师不存在");
        Long userId = manicurist.getUserId();
        User user = userService.getById(userId);
        user.setUserRole(0);
        boolean update = userService.updateById(user);
        ThrowUtils.throwIf(!update, ErrorCode.PARAMS_ERROR, "操作失败");

        boolean result = this.removeById(id);
        ThrowUtils.throwIf(!result, ErrorCode.PARAMS_ERROR, "操作失败");
    }

    @Override
    public QueryWrapper<Manicurist> getQueryWrapper(ManicuristQueryRequest manicuristQueryRequest) {
        if (manicuristQueryRequest == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "请求参数为空");
        }

        Long id = manicuristQueryRequest.getId();
        Long userId = manicuristQueryRequest.getUserId();
        Long businessId = manicuristQueryRequest.getBusinessId();
        String name = manicuristQueryRequest.getName();
        Integer gender = manicuristQueryRequest.getGender();
        String Phone = manicuristQueryRequest.getPhone();
        String email = manicuristQueryRequest.getEmail();
        Date employment_date = manicuristQueryRequest.getEmployment_date();
        String specialties = manicuristQueryRequest.getSpecialties();
        BigDecimal rating = manicuristQueryRequest.getRating();
        BigDecimal salary = manicuristQueryRequest.getSalary();


        QueryWrapper<Manicurist> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(ObjectUtils.isNotEmpty(id), "id", id);
        queryWrapper.eq(ObjectUtils.isNotEmpty(userId), "userId", userId);
        queryWrapper.eq(ObjectUtils.isNotEmpty(businessId), "businessId", businessId);
        queryWrapper.eq(ObjectUtils.isNotEmpty(name), "name", name);
        queryWrapper.like(ObjectUtils.isNotEmpty(gender), "gender", gender);
        queryWrapper.eq(ObjectUtils.isNotEmpty(Phone), "Phone", Phone);
        queryWrapper.eq(ObjectUtils.isNotEmpty(email), "email", email);
        queryWrapper.like(ObjectUtils.isNotEmpty(employment_date), "employment_date", employment_date);
        queryWrapper.like(ObjectUtils.isNotEmpty(specialties), "specialties", specialties);
        queryWrapper.like(ObjectUtils.isNotEmpty(rating), "rating", rating);
        queryWrapper.like(ObjectUtils.isNotEmpty(salary), "salary", salary);
        String sortField = manicuristQueryRequest.getSortField();
        String sortOrder = manicuristQueryRequest.getSortOrder();
        queryWrapper.orderBy(SqlUtils.validSortField(sortField), sortOrder.equals(CommonConstant.SORT_ORDER_ASC),
                sortField);

        return queryWrapper;
    }
}




